@@ -113,8 +113,8 @@ ok_add_files (GtkWidget *widget, NewDlData *new_dl_data)
         if (url == NULL)
             error_msg = g_strconcat (error_msg, _ ("already in the list"),
                                      NULL);
-        error = gnome_message_box_new (error_msg, GNOME_MESSAGE_BOX_ERROR,
-                                       GNOME_STOCK_BUTTON_OK, NULL);
+        error = gnome_error_dialog_parented (
+            error_msg, GTK_WINDOW (new_dl_data->dlg));
         gnome_dialog_run_and_close (GNOME_DIALOG (error));
     }
 
