@@ -63,11 +63,8 @@ ok_new_file (GtkWidget *widget, NewDlData *new_dl_data)
     /* Get the URL data and make sure it's right */
     url = g_strdup (gtk_entry_get_text (GTK_ENTRY (new_dl_data->url)));
     if (strncasecmp (url, "http://", 7) && strncasecmp (url, "ftp://", 6)) {
-	error = gnome_message_box_new (
-	    _ ("Invalid URL"), GNOME_MESSAGE_BOX_ERROR, 
-	    GNOME_STOCK_BUTTON_OK, NULL);
-	gnome_dialog_set_parent (GNOME_DIALOG (error), 
-                                 GTK_WINDOW (new_dl_data->dlg));
+        error = gnome_error_dialog_parented (
+            _ ("Invalid URL"), GTK_WINDOW (new_dl_data->dlg));
 	gnome_dialog_run_and_close (GNOME_DIALOG (error));
         g_free (url);
 	return;
@@ -85,12 +82,9 @@ ok_new_file (GtkWidget *widget, NewDlData *new_dl_data)
      * ask there for download depth and get the available files to download. 
      * Then the user can remove what he doesn't want. */
     if (strlen (filename) == 0) {
-	error = gnome_message_box_new (
-	    _ ("Multiple download not implemented yet"), 
-            GNOME_MESSAGE_BOX_ERROR, 
-	    GNOME_STOCK_BUTTON_OK, NULL);
-	gnome_dialog_set_parent (GNOME_DIALOG (error), 
-                                 GTK_WINDOW (new_dl_data->dlg));
+        error = gnome_error_dialog_parented (
+            _ ("Multiple download not implemented yet"),
+            GTK_WINDOW (new_dl_data->dlg));
 	gnome_dialog_run_and_close (GNOME_DIALOG (error));
         g_free (url);
 	return;
@@ -132,10 +126,11 @@ ok_new_file (GtkWidget *widget, NewDlData *new_dl_data)
             /* Unknown code */
             error_msg = g_strconcat ("", NULL);
         }
-        error = gnome_message_box_new (error_msg, GNOME_MESSAGE_BOX_ERROR,
-                                       GNOME_STOCK_BUTTON_OK, NULL);
+        error = gnome_error_dialog_parented (
+            error_msg, GTK_WINDOW (new_dl_data->dlg));
         gnome_dialog_run_and_close (GNOME_DIALOG (error));
         g_free (error_msg);
+        return;
     }
     
     /* Destroy the dialog box and free unused that */
