@@ -92,7 +92,7 @@ impl_GTM_Download_add_url(impl_POA_GTM_Download * servant,
    FileData *file_data;
    
    file_data = file_data_create (url, dir, !disable_proxy, !disable_auto_dl);
-   retval = file_list_add (GTK_CLIST (dl_file_list), file_data);
+   retval = file_list_single_add (GTK_CLIST (dl_file_list), file_data);
    if (retval == FALSE)
        file_data_free (file_data);
 
