@@ -95,11 +95,12 @@ ok_new_file (GtkWidget *widget, NewDlData *new_dl_data)
 
 	error_msg = g_strconcat (_ ("URL:\n"), url, "\n",
 				 _ ("already in the list"), NULL);
-	error = gnome_message_box_new (error_msg, GNOME_MESSAGE_BOX_ERROR,
-				       GNOME_STOCK_BUTTON_OK, NULL);
+        error = gnome_error_dialog_parented (
+            error_msg, GTK_WINDOW (new_dl_data->dlg));
 	gnome_dialog_run_and_close (GNOME_DIALOG (error));
 	file_data_free (file_data);
 	g_free (error_msg);
+        return;
     }
     /* If dialog changes default download dir update the def dl dir */
     change_default_download_dir (dl_policy.download_dir);
@@ -158,17 +159,17 @@ dialog_new_contents (NewDlData *new_dl_data)
     g_return_if_fail (new_dl_data != NULL);
 
     switch (gtm_pref.presume_protocol) {
-    case 0:
-        default_protocol = g_strconcat("", NULL);
-        break;
-    case 1:
-        default_protocol = g_strconcat("http://", NULL);
-        break;
-    case 2:
-	default_protocol = g_strconcat("ftp://", NULL);
-	break;
-    default:
-	default_protocol = g_strconcat("", NULL);
+        case 0:
+            default_protocol = g_strconcat("", NULL);
+            break;
+        case 1:
+            default_protocol = g_strconcat("http://", NULL);
+            break;
+        case 2:
+            default_protocol = g_strconcat("ftp://", NULL);
+            break;
+        default:
+            default_protocol = g_strconcat("", NULL);
     }
     /* URL */
     label = gtk_label_new (_ ("Please enter URL of the file to download:"));
@@ -229,5 +230,3 @@ dialog_new (void)
     /* Show the dialog box and every thing it contains */
     gtk_widget_show_all (new_dl_data->dlg);
 }
-
-
