@@ -81,13 +81,15 @@ typedef struct
     GtkWidget *confirm_remove_completed;        /* Toggle button */
     GtkWidget *confirm_restart;                 /* Toggle button */
     GtkWidget *manual_stop_disables_auto_dl;    /* Toggle button */
-    GtkWidget *show_dl_info_page;               /* Toggle button */
     GtkWidget *confirm_dnd_url;                 /* Toggle button */
     GtkWidget *use_sound;                       /* Toggle button */
     GtkWidget *use_beep;                        /* Toggle button */
     GtkWidget *dir_list;                        /* CList */
     GtkWidget *stop_dl_on_link_loss;            /* Toggle button */
     GtkWidget *presume_protocol[NUM_PRESUME_PROTOCOLS]; /* Toggle button */
+    GtkWidget *load_pause_auto_dl;              /* Toggle button */
+    GtkWidget *auto_hide_dl_info_page;          /* Toggle button */
+    GtkWidget *auto_hide_dl_info_page_timeout;  /* Spin */
 } PrefDialogData;
 
 
@@ -122,10 +124,8 @@ apply_prefs_auto (PrefDialogData *pref)
     gnome_config_set_string("interface", gtm_pref.interface);
 
     /* Check interface time */
-    gtm_pref.chk_interf_time = gtk_spin_button_get_value_as_int (
-        GTK_SPIN_BUTTON (pref->chk_interf_time));
-    gnome_config_set_int ("chk_interf_time", 
-                          gtm_pref.chk_interf_time);
+    update_check_interface_timeout (gtk_spin_button_get_value_as_int (
+        GTK_SPIN_BUTTON (pref->chk_interf_time)));
 
     /* Number of autodownload */
     gtm_pref.num_of_auto_download =
@@ -147,6 +147,13 @@ apply_prefs_auto (PrefDialogData *pref)
             GTK_TOGGLE_BUTTON (pref->stop_dl_on_link_loss));
     gnome_config_set_bool ("stop_dl_on_link_loss",
                            gtm_pref.stop_dl_on_link_loss);
+
+    /* Load pause auto download */
+    gtm_pref.load_pause_auto_dl =
+        gtk_toggle_button_get_active (
+            GTK_TOGGLE_BUTTON (pref->load_pause_auto_dl));
+    gnome_config_set_bool ("load_pause_auto_dl",
+                           gtm_pref.load_pause_auto_dl);
 }
 
 static void
@@ -265,12 +272,12 @@ apply_prefs_display (PrefDialogData *pref)
         GTK_TOGGLE_BUTTON (pref->show_page_stat));
     gnome_config_set_bool ("show_page_stat", gtm_pref.show_page_stat);
 
-    /* Show download info page */
-    gtm_pref.show_dl_info_page = gtk_toggle_button_get_active (
-        GTK_TOGGLE_BUTTON (pref->show_dl_info_page));
-    main_window_update_dl_info_page_visibility ();
-    gnome_config_set_bool ("show_dl_info_page",
-                           gtm_pref.show_dl_info_page);
+    /* Auto hide download info page */
+    main_window_update_auto_hide_dl_info_page (
+        gtk_toggle_button_get_active (
+            GTK_TOGGLE_BUTTON (pref->auto_hide_dl_info_page)),
+        gtk_spin_button_get_value_as_int (
+            GTK_SPIN_BUTTON (pref->auto_hide_dl_info_page_timeout)));
 }
 
 static void
@@ -363,6 +370,14 @@ pref_modified_cb (GtkWidget *widget, PrefDialogData *pref)
         gtk_widget_set_sensitive (pref->proxy_ftp, FALSE);
     }
 
+    /* Change the sensitivity of the auto hide download info page timeout */
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
+        pref->auto_hide_dl_info_page)))
+        gtk_widget_set_sensitive (pref->auto_hide_dl_info_page_timeout, TRUE);
+    else
+        gtk_widget_set_sensitive (pref->auto_hide_dl_info_page_timeout, FALSE);
+    
+
     /* Tell to preferty box that data changed */
     gnome_property_box_changed (GNOME_PROPERTY_BOX (pref->pbox));
 }
@@ -477,17 +492,15 @@ create_auto_page (PrefDialogData *pref)
     /* Check interface time */
     hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-    label = gtk_label_new (_ ("Check interface time:"));
+    label = gtk_label_new (_ ("Check interface time (ms):"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     adjustment = gtk_adjustment_new (1000, 100, 10000, 1, 100, 100);
     pref->chk_interf_time = 
         gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), 1, 0);
     gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (pref->chk_interf_time), 
                                  TRUE);
-    gtk_box_pack_start (GTK_BOX (hbox), pref->chk_interf_time, FALSE, FALSE, 
+    gtk_box_pack_start (GTK_BOX (hbox), pref->chk_interf_time, TRUE, TRUE, 
                         0);
-    label = gtk_label_new ("ms");
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     
     /* Simultaneos downloads */
     hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
@@ -497,7 +510,7 @@ create_auto_page (PrefDialogData *pref)
     adjustment = gtk_adjustment_new (1, 0, INT_MAX, 1, 100, 100);
     pref->simul = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), 1, 0);
     gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (pref->simul), TRUE);
-    gtk_box_pack_start (GTK_BOX (hbox), pref->simul, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), pref->simul, TRUE, TRUE, 0);
 
     /* Manual stop disables auto download */
     pref->manual_stop_disables_auto_dl = 
@@ -512,6 +525,12 @@ create_auto_page (PrefDialogData *pref)
     gtk_box_pack_start (GTK_BOX (vbox), pref->stop_dl_on_link_loss,
                         FALSE, FALSE, 0);
 
+    /* Load pause auto download */
+    pref->load_pause_auto_dl =
+        gtk_check_button_new_with_label (_ ("Load pause auto download state"));
+    gtk_box_pack_start (GTK_BOX (vbox), pref->load_pause_auto_dl,
+                        FALSE, FALSE, 0);
+
     /* Set current preferences */
     gtk_entry_set_text(GTK_ENTRY(pref->interface), gtm_pref.interface);
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (pref->chk_interf_time), 
@@ -524,6 +543,9 @@ create_auto_page (PrefDialogData *pref)
     gtk_toggle_button_set_active (
         GTK_TOGGLE_BUTTON (pref->stop_dl_on_link_loss),
         gtm_pref.stop_dl_on_link_loss);
+    gtk_toggle_button_set_active (
+        GTK_TOGGLE_BUTTON (pref->load_pause_auto_dl),
+        gtm_pref.load_pause_auto_dl);
 
     /* Connect the signal that acknowledges the change on the widget to 
      * function that turns on the OK and APPLY buttons */
@@ -542,6 +564,9 @@ create_auto_page (PrefDialogData *pref)
     gtk_signal_connect (GTK_OBJECT (pref->stop_dl_on_link_loss),
                         "toggled", GTK_SIGNAL_FUNC (pref_modified_cb),
                         (gpointer) pref);
+    gtk_signal_connect (GTK_OBJECT (pref->load_pause_auto_dl),
+                        "toggled", GTK_SIGNAL_FUNC (pref_modified_cb),
+                        (gpointer) pref);
 
     return vbox;
 }
@@ -588,7 +613,7 @@ create_download_page (PrefDialogData *pref)
     pref->num_retries = 
         gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), 1, 0);
     gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (pref->num_retries), TRUE);
-    gtk_box_pack_start (GTK_BOX (hbox), pref->num_retries, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), pref->num_retries, TRUE, TRUE, 0);
 
     /* Use passive ftp */
     pref->use_passive_ftp = 
@@ -783,17 +808,15 @@ create_display_page (PrefDialogData *pref)
     /* File list refresh interval */
     hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-    label = gtk_label_new (_ ("File list refresh rate:"));
+    label = gtk_label_new (_ ("File list refresh rate (ms):"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     adjustment = gtk_adjustment_new (1000, 100, 10000, 1, 100, 100);
     pref->file_list_refresh = 
         gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), 1, 0);
     gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (pref->file_list_refresh), 
                                  TRUE);
-    gtk_box_pack_start (GTK_BOX (hbox), pref->file_list_refresh, FALSE, FALSE,
+    gtk_box_pack_start (GTK_BOX (hbox), pref->file_list_refresh, TRUE, TRUE,
                         0);
-    label = gtk_label_new ("ms");
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
     /* Show list statistics */
     pref->show_list_stat = 
@@ -805,11 +828,22 @@ create_display_page (PrefDialogData *pref)
         gtk_check_button_new_with_label (_ ("Show page statistics"));
     gtk_box_pack_start (GTK_BOX (vbox), pref->show_page_stat, FALSE, FALSE, 0);
 
-    /* Show download info page */
-    pref->show_dl_info_page = 
-        gtk_check_button_new_with_label (_ ("Show download info page"));
-    gtk_box_pack_start (GTK_BOX (vbox), pref->show_dl_info_page, FALSE,
+    /* Auto hide download info page */
+    pref->auto_hide_dl_info_page = 
+        gtk_check_button_new_with_label (_ ("Auto hide download info page"));
+    gtk_box_pack_start (GTK_BOX (vbox), pref->auto_hide_dl_info_page, FALSE,
                         FALSE, 0);
+    hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
+    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+    label = gtk_label_new (_ ("Auto hide download info page timeout (ms):"));
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    adjustment = gtk_adjustment_new (1000, 1000, 50000, 1000, 1000, 1000);
+    pref->auto_hide_dl_info_page_timeout = 
+        gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), 1, 0);
+    gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (
+        pref->auto_hide_dl_info_page_timeout), TRUE);
+    gtk_box_pack_start (GTK_BOX (hbox), pref->auto_hide_dl_info_page_timeout,
+                        TRUE, TRUE, 0);
 
     /* Set current preferences */
     for (i = 0; i < NUM_TOOLBAR_TYPES; i++) {
@@ -825,8 +859,12 @@ create_display_page (PrefDialogData *pref)
                                   gtm_pref.show_list_stat);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pref->show_page_stat),
                                   gtm_pref.show_page_stat);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pref->show_dl_info_page),
-                                  gtm_pref.show_dl_info_page);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
+        pref->auto_hide_dl_info_page), gtm_pref.auto_hide_dl_info_page);
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (
+        pref->auto_hide_dl_info_page_timeout),
+                               (gfloat) 
+                               gtm_pref.auto_hide_dl_info_page_timeout);
 
     /* Connect the signal that acknowledges the change on the widget to 
      * function that turns on the OK and APPLY buttons */
@@ -843,9 +881,12 @@ create_display_page (PrefDialogData *pref)
     gtk_signal_connect (GTK_OBJECT (pref->show_page_stat), "toggled",
                         GTK_SIGNAL_FUNC (pref_modified_cb),
                         (gpointer) pref);
-    gtk_signal_connect (GTK_OBJECT (pref->show_dl_info_page), "toggled",
+    gtk_signal_connect (GTK_OBJECT (pref->auto_hide_dl_info_page), "toggled",
                         GTK_SIGNAL_FUNC (pref_modified_cb),
                         (gpointer) pref);
+    gtk_signal_connect (GTK_OBJECT (pref->auto_hide_dl_info_page_timeout), 
+                        "changed", GTK_SIGNAL_FUNC (pref_modified_cb),
+                        (gpointer) pref);
 
     return vbox;
 }
