@@ -29,6 +29,7 @@
 #include "file-data.h"
 #include "file-list.h"
 #include "download-info.h"
+#include "dialogs.h"
 #include "main-window.h"
 #include "wget-log.h"
 #include "download-dirs.h"
@@ -132,10 +133,8 @@ file_data_set_state (FileData *file_data, DlState state, gboolean sync)
         file_list_set_row_state (GTK_CLIST (file_data->file_list), row, state);
         menu_toolbar_set_state (GTK_CLIST (file_data->file_list));
         file_list_menu_popup_set_state (GTK_CLIST (file_data->file_list));
-        if (row == GTK_CLIST (file_data->file_list)->focus_row
-            && g_list_find (GTK_CLIST (file_data->file_list)->selection,
-                            (gpointer) row) != NULL)
-            download_info_update_state (file_data);
+        download_info_update ();
+        dialog_prop (FALSE);
     }
 }
 
@@ -143,7 +142,6 @@ void
 file_data_set_total_size (FileData *file_data, guint32 total_size,
                           gboolean sync)
 {
-    gint row;
     gchar *path;
 
     file_data->total_size = total_size;
@@ -153,19 +151,20 @@ file_data_set_total_size (FileData *file_data, guint32 total_size,
         gnome_config_sync ();
     g_free (path);
     if (file_data->file_list != NULL) {
-        row = gtk_clist_find_row_from_data (GTK_CLIST (file_data->file_list),
-                                            file_data);
-        if (row == GTK_CLIST (file_data->file_list)->focus_row
-            && g_list_find (GTK_CLIST (file_data->file_list)->selection,
-                            (gpointer) row) != NULL)
-            download_info_update_total_size (file_data);
+        download_info_update ();
+        dialog_prop (FALSE);
     }
 }
 
-void file_data_set_url (FileData *file_data, gchar *url)
+void
+file_data_set_url (FileData *file_data, gchar *url)
 {
     gchar *path;
 
+    /* Check if the URL really changed before doing anything */
+    if (g_strcasecmp (url, file_data->url) == 0)
+        return;
+
     /* Before changing the URL we must stop the download */
     file_data_stop_download (file_data);
     g_free (file_data->url);
@@ -175,9 +174,14 @@ void file_data_set_url (FileData *file_data, gchar *url)
     gnome_config_set_string (path, file_data->url);
     gnome_config_sync ();
     g_free (path);
+    if (file_data->file_list != NULL) {
+        download_info_update ();
+        dialog_prop (FALSE);
+    }
 }
 
-int file_data_url_valid (const gchar *url)
+int
+file_data_url_valid (const gchar *url)
 {
     return (strncasecmp (url, "http://", 7) == 0 ||
             strncasecmp (url, "ftp://", 6) == 0 );
@@ -194,6 +198,10 @@ void file_data_set_use_proxy (FileData *file_data,
     gnome_config_set_bool (path, !file_data->use_proxy);
     gnome_config_sync ();
     g_free (path);
+    if (file_data->file_list != NULL) {
+        download_info_update ();
+        dialog_prop (FALSE);
+    }
 }
 
 void file_data_set_use_auto_dl (FileData *file_data,
@@ -207,6 +215,10 @@ void file_data_set_use_auto_dl (FileData *file_data,
     gnome_config_set_bool (path, !file_data->use_auto_dl);
     gnome_config_sync ();
     g_free (path);
+    if (file_data->file_list != NULL) {
+        download_info_update ();
+        dialog_prop (FALSE);
+    }
 }
 
 void
@@ -248,10 +260,8 @@ file_data_update_statistics (FileData *file_data, gboolean sync)
                                             file_data);
         file_list_set_row_statistics (GTK_CLIST (file_data->file_list), row, 
                                       file_data);
-        if (row == GTK_CLIST (file_data->file_list)->focus_row
-            && g_list_find (GTK_CLIST (file_data->file_list)->selection,
-                            (gpointer) row) != NULL)
-            download_info_update_statistics (file_data);
+        download_info_update ();
+        dialog_prop (FALSE);
         file_list_update_statistics (GTK_CLIST (file_data->file_list));
     }
     
@@ -459,7 +469,7 @@ file_data_stop_download (FileData *file_data)
 
     /* Check if stop action disables auto download */
     if (gtm_pref.manual_stop_disables_auto_dl)
-        file_data->use_auto_dl = FALSE;
+        file_data_set_use_auto_dl (file_data, FALSE);
 }
 
 void
@@ -468,9 +478,9 @@ file_data_restart_download (FileData *file_data)
     /* First stop the download, clear download info and remove downloaded 
      * file */
     file_data_stop_download (file_data);
-    file_data_set_state (file_data, DL_NOT_STARTED, TRUE);
-    file_data->total_time = 0;
     unlink (file_data->local_filename);
+    file_data->total_time = 0;
+    file_data_set_state (file_data, DL_NOT_STARTED, TRUE);
 
     /* Now start again the download */
     file_data_start_download (file_data);
