@@ -28,6 +28,7 @@
 #include "finish.xpm"
 #include "run.xpm"
 #include "stop.xpm"
+#include "unstarted.xpm"
 
 /* Timeout for auto-scroll on drag */
 #define SCROLL_TIMEOUT 100
@@ -147,8 +148,6 @@ file_list_menu_popup_set_state (GtkCList *file_list)
 static int
 file_list_event (GtkCList *file_list, GdkEvent *event, GtkMenu *popup)
 {
-    gint row, column;
-    static gint row_pressed = -1;
     GdkEventButton *button_event = (GdkEventButton *) event;
 	
     if (event->type == GDK_BUTTON_PRESS && button_event->button == 3) {
@@ -157,30 +156,7 @@ file_list_event (GtkCList *file_list, GdkEvent *event, GtkMenu *popup)
         gtk_menu_popup (popup, NULL, NULL, NULL, NULL, 3, 
                         button_event->time);
         return TRUE;
-    } else if (event->type == GDK_BUTTON_PRESS
-               && button_event->button == 1) {
-        /* Left mouse button pressed */
-        if (gtk_clist_get_selection_info (file_list, button_event->x,
-                                          button_event->y, &row, &column) == 0)
-            row_pressed = -1;
-        else
-            row_pressed = row;
-    } else if (event->type == GDK_BUTTON_RELEASE
-               && button_event->button == 1) {
-        /* Left mouse button released */
-        FileData *file_data;
-
-        if (gtk_clist_get_selection_info (file_list, button_event->x,
-                                          button_event->y, &row, &column) == 0
-            && row != row_pressed)
-            return FALSE;
-
-        file_data =
-            (FileData *) gtk_clist_get_row_data (file_list,
-                                                 file_list->focus_row);
-        download_info_update (file_data);
-        dialog_prop (FALSE, file_data);
-    }
+    } 
     return FALSE;
 }
 
@@ -201,15 +177,11 @@ static void
 file_list_select_row (GtkCList *file_list, gint row, gint column, 
 		      GdkEventButton *event, gpointer data)
 {
-    FileData *file_data;
-    
-    file_data = (FileData *) gtk_clist_get_row_data (file_list,
-                                                     file_list->focus_row);
     menu_toolbar_set_state (file_list);
     menu_toolbar_set_auto_dl (file_list);
     file_list_menu_popup_set_state (file_list);
-    download_info_update (file_data);
-    dialog_prop (FALSE, file_data);
+    download_info_update ();
+    dialog_prop (FALSE);
 }
 
 static void 
@@ -219,11 +191,8 @@ file_list_unselect_row (GtkCList *file_list, gint row, gint column,
     //menu_toolbar_set_state (file_list);
     //menu_toolbar_set_auto_dl (file_list);
     //file_list_menu_popup_set_state (file_list);
-    if (g_list_find (file_list->selection,
-                     (gpointer) file_list->focus_row) == NULL) {
-        download_info_update (NULL);
-        dialog_prop (FALSE, NULL);
-    }
+    download_info_update ();
+    dialog_prop (FALSE);
 }
 
 /* Save the new list order when the user moves a row. */
@@ -531,17 +500,24 @@ file_list_create (void)
 void
 file_list_set_row_state (GtkCList *file_list, gint row, DlState state)
 {
-    static GdkPixmap *pm_stop = NULL, *pm_run = NULL, *pm_finish = NULL;
+    static GdkPixmap *pm_stop = NULL, *pm_run = NULL, *pm_finish = NULL,
+        *pm_unstarted = NULL;
     static GdkBitmap *pm_stop_mask = NULL, *pm_run_mask = NULL,
-        *pm_finish_mask = NULL;
+        *pm_finish_mask = NULL, *pm_unstarted_mask = NULL;
 
     if (pm_stop == NULL) {
         gdk_imlib_data_to_pixmap (finish_xpm, &pm_finish, &pm_finish_mask);
         gdk_imlib_data_to_pixmap (run_xpm, &pm_run, &pm_run_mask);
         gdk_imlib_data_to_pixmap (stop_xpm, &pm_stop, &pm_stop_mask);
+        gdk_imlib_data_to_pixmap (unstarted_xpm, &pm_unstarted,
+                                  &pm_unstarted_mask);
     }
     switch (state) {
         case DL_NOT_STARTED:
+            gtk_clist_set_pixmap (GTK_CLIST (file_list), row,
+                                  FILE_LIST_COL_STATE, pm_unstarted,
+                                  pm_unstarted_mask);
+            break;
         case DL_NOT_RUNNING:
             gtk_clist_set_pixmap (GTK_CLIST (file_list), row,
                                   FILE_LIST_COL_STATE, pm_stop, pm_stop_mask);
@@ -593,7 +569,7 @@ file_list_set_row_statistics (GtkCList *file_list, gint row,
     if (file_data->state != DL_NOT_STARTED
         && file_data->state != DL_NOT_RUNNING
         && file_data->state != DL_COMPLETED) {
-        if (retr_size != 0)
+        if (file_data->total_size != 0 && retr_size != 0)
             estimated =
                 (((gfloat) (file_data->total_size
                             - file_data->session_start_size)
@@ -603,7 +579,8 @@ file_list_set_row_statistics (GtkCList *file_list, gint row,
         else
             estimated = 0;
     } else {
-        if (file_data->cur_size != 0 && file_data->state != DL_COMPLETED)
+        if (file_data->total_size != 0 && file_data->cur_size != 0
+            && file_data->state != DL_COMPLETED)
             estimated =
                 ((gfloat) file_data->total_size * file_data->total_time)
                 / file_data->cur_size;
@@ -651,24 +628,27 @@ file_list_simple_add (GtkCList *file_list, FileData *file_data,
     if (check_duplicates &&
         (file_list_find_url (file_list, file_data->url) != -1))
 	return FALSE;
-    /* TODO:  Error if this is startup */
 
     /* Check if in the download directory there already is a */
-    /* file withe the same name                              */
-    local_file = g_strconcat(file_data->dir, file_data->filename, NULL);
-    fp = fopen(local_file, "r");
-    if (fp != NULL && file_data->state != DL_COMPLETED) {
+    /* file with the same name                              */
+    local_file = g_strconcat (file_data->dir, file_data->filename, NULL);
+    fp = fopen (local_file, "r");
+    if (check_duplicates && fp != NULL && file_data->state != DL_COMPLETED) {
 	gchar *error_msg;
 
 	fclose(fp);
 
-	error_msg = g_strconcat (_ ("File:\n"), local_file, "\n",
-				 _ ("already exist"), NULL);
-	error = gnome_message_box_new (error_msg, GNOME_MESSAGE_BOX_ERROR,
-				       GNOME_STOCK_BUTTON_OK, NULL);
+	error_msg = 
+            g_strconcat (_ ("File:\n"), local_file, "\n",
+                         _ ("already exists and it was replaced."),
+                         NULL);
+        error = gnome_error_dialog_parented (error_msg, 
+                                                GTK_WINDOW (gtm_app));
 	gnome_dialog_run_and_close (GNOME_DIALOG (error));
 	g_free (error_msg);
+        unlink (local_file);
     }
+    g_free (local_file);
 
     file_data->file_list = GTK_WIDGET (file_list);
     data[FILE_LIST_COL_STATE] = NULL;
@@ -757,6 +737,7 @@ file_list_remove_selection (GtkCList *file_list, gboolean completed,
 static void
 file_list_zero_statistics (FileListStats *stats) 
 {
+    stats->num_unstarted = 0;
     stats->num_stopped = 0;
     stats->num_running = 0;
     stats->num_completed = 0;
@@ -782,7 +763,9 @@ file_list_update_statistics (GtkCList *file_list)
         file_data = gtk_clist_get_row_data (file_list, i);
 
         switch (file_data->state) {
-        case DL_NOT_STARTED: 
+        case DL_NOT_STARTED:
+            list_stats->num_unstarted++;
+            break;
         case DL_NOT_RUNNING:
             list_stats->num_stopped++;
             list_stats->size_stopped += file_data->total_size;
@@ -1018,7 +1001,8 @@ file_list_start_auto_downloads (GtkCList *file_list)
 
     /* check before to start to download */
     row = 0;
-    while (num_of_download < gtm_pref.num_of_auto_download
+    while (!gtm_pref.pause_auto_dl
+           && num_of_download < gtm_pref.num_of_auto_download
            && (file_data = 
                gtk_clist_get_row_data (GTK_CLIST (file_list), row)) != NULL) {
         if (file_data->use_auto_dl == TRUE)
@@ -1061,3 +1045,18 @@ file_list_unselect_all (GtkCList *file_list)
     if (file_list->rows > 0)
         gtk_clist_unselect_all (file_list);
 }
+
+FileData *
+file_list_get_unique_selection (GtkCList *file_list)
+{
+    FileData *file_data;
+
+    if (file_list->selection == NULL || file_list->selection->next != NULL)
+        file_data = NULL;
+    else
+        file_data = (FileData *)
+            gtk_clist_get_row_data (file_list,
+                                    (gint) file_list->selection->data);
+
+    return file_data;
+}
