@@ -24,12 +24,18 @@
 #include "file-list.h"
 #include "dialogs.h"
 #include "download-info.h"
+#include "log.h"
 #include "main-window.h"
 #include "robot.xpm"
+#include "pause-robot.xpm"
+#include "dl-infopage.xpm"
 
 /* Download info page */
 static GtkWidget *download_info;
 
+/* Auto hide download info page timeout id */
+static gint auto_hide_dlip_timeout_id = -1;
+
 
 /* Callbacks functions */
 static void
@@ -137,16 +143,7 @@ preferences_cmd (void)
 void
 properties_cmd (GtkWidget *widget, gpointer data)
 {
-    FileData *file_data;
-
-    if (g_list_find (GTK_CLIST (dl_file_list)->selection,
-                     (gpointer) GTK_CLIST (dl_file_list)->focus_row) != NULL)
-        file_data = (FileData *)
-            gtk_clist_get_row_data (GTK_CLIST (dl_file_list),
-                                    GTK_CLIST (dl_file_list)->focus_row);
-    else
-        file_data = NULL;
-    dialog_prop (TRUE, file_data);
+    dialog_prop (TRUE);
 }
 
 static void
@@ -186,16 +183,34 @@ toggle_auto_dl_cmd (GtkWidget *widget, gpointer data)
         p = p->next;
     }
     gtk_clist_thaw (file_list);
+}
 
-    if (g_list_find (file_list->selection,
-                     (gpointer) file_list->focus_row) != NULL)
-        file_data = (FileData *)
-            gtk_clist_get_row_data (file_list,
-                                    file_list->focus_row);
-    else
-        file_data = NULL;
-    download_info_update (file_data);
-    dialog_prop (FALSE, file_data);
+static void
+toggle_pause_auto_dl_cmd (GtkWidget *widget, gpointer data)
+{
+    gtm_pref.pause_auto_dl = !gtm_pref.pause_auto_dl;
+    gnome_config_set_bool ("/gtm/Preferences/pause_auto_dl",
+                           gtm_pref.pause_auto_dl);
+    menu_toolbar_update_pause_auto_dl (GTK_CLIST (dl_file_list));
+}
+
+static void
+toggle_dl_info_page_cmd (GtkWidget *widget, gpointer data)
+{
+    main_window_set_dl_info_page_visibility (GTK_CLIST (dl_file_list),
+                                             !gtm_pref.show_dl_info_page);
+}
+
+static gint
+auto_hide_dl_info_page_cmd (gpointer data)
+{
+    /* Remove the timeout */
+    auto_hide_dlip_timeout_id = -1;
+
+    /* Hide the download info page */
+    main_window_set_dl_info_page_visibility (GTK_CLIST (dl_file_list), FALSE);
+
+    return FALSE;
 }
 
 
@@ -250,6 +265,11 @@ static GnomeUIInfo main_menu_download[] = {
 			    N_ ("Restart the download of selected files from "
                                 "the beginning"), restart_cmd, 
 			    GNOME_STOCK_MENU_REFRESH),
+    GNOMEUIINFO_SEPARATOR,
+#define MAIN_MENU_DOWNLOAD_PAUSE_AUTO_DL 4
+    GNOMEUIINFO_TOGGLEITEM (N_ ("Pause Auto Dl"),
+                            N_ ("Pause robot starting the auto download"),
+                            toggle_pause_auto_dl_cmd, pause_robot_xpm),
     GNOMEUIINFO_END
 };
 
@@ -309,12 +329,20 @@ static GnomeUIInfo main_toolbar[] = {
                                 "the beginning"), restart_cmd,
 			    GNOME_STOCK_PIXMAP_REFRESH),
     GNOMEUIINFO_SEPARATOR,
-#define MAIN_TOOLBAR_TOGGLE_AUTO_DL 8
+#define MAIN_TOOLBAR_PAUSE_AUTO_DL 8
+    GNOMEUIINFO_TOGGLEITEM (N_ ("Pause Auto Dl"),
+                            N_ ("Pause robot starting the auto download"),
+                            toggle_pause_auto_dl_cmd, pause_robot_xpm),
+#define MAIN_TOOLBAR_TOGGLE_AUTO_DL 9
     GNOMEUIINFO_TOGGLEITEM (N_ ("Toggle Auto Dl"),
                             N_ ("Toggle auto download of selected files"),
                             toggle_auto_dl_cmd, robot_xpm),
     GNOMEUIINFO_SEPARATOR,
-#define MAIN_TOOLBAR_PROPERTIES 10
+#define MAIN_TOOLBAR_DL_INFO_PAGE 11
+    GNOMEUIINFO_TOGGLEITEM (N_ ("Dl Info Page"),
+                            N_ ("Toggle download info page"),
+                            toggle_dl_info_page_cmd, dl_infopage_xpm),
+#define MAIN_TOOLBAR_PROPERTIES 12
     GNOMEUIINFO_ITEM_STOCK (N_ ("Properties"),
                             N_ ("Open properties for selected file"),
                             properties_cmd, GNOME_STOCK_PIXMAP_PROPERTIES),
@@ -325,6 +353,28 @@ static GnomeUIInfo main_toolbar[] = {
 };
 
 
+/* Function to update the auto hide download info page timeout */
+static void
+update_auto_hide_dl_info_page_timeout (void)
+{
+    if (gtm_pref.auto_hide_dl_info_page) {
+        if (auto_hide_dlip_timeout_id != -1)
+            gtk_timeout_remove (auto_hide_dlip_timeout_id);
+        if (gtm_pref.show_dl_info_page)
+            auto_hide_dlip_timeout_id =
+                gtk_timeout_add (gtm_pref.auto_hide_dl_info_page_timeout,
+                                 auto_hide_dl_info_page_cmd, NULL);
+        else
+            auto_hide_dlip_timeout_id = -1;
+    } else {
+        if (auto_hide_dlip_timeout_id != -1) {
+            gtk_timeout_remove (auto_hide_dlip_timeout_id);
+            auto_hide_dlip_timeout_id = -1;
+        }
+    }
+}
+
+
 /* Function to set the state of the menu and toolbar according to the 
  * selection on the file list */
 void
@@ -503,6 +553,44 @@ menu_toolbar_set_auto_dl (GtkCList *file_list)
 }
 
 
+/* Function to set the pause auto download on the menu and toolbar */
+void
+menu_toolbar_update_pause_auto_dl (GtkCList *file_list)
+{
+    /* Disable the callbacks to pause_auto_dl_cmd */
+    gtk_signal_handler_block_by_func (
+        GTK_OBJECT (
+            main_menu_download[MAIN_MENU_DOWNLOAD_PAUSE_AUTO_DL].widget),
+        GTK_SIGNAL_FUNC (toggle_pause_auto_dl_cmd),
+        file_list);
+    gtk_signal_handler_block_by_func (
+        GTK_OBJECT (main_toolbar[MAIN_TOOLBAR_PAUSE_AUTO_DL].widget),
+        GTK_SIGNAL_FUNC (toggle_pause_auto_dl_cmd),
+        file_list);
+
+    /* Now safely set the new state */
+    gtk_check_menu_item_set_active (
+        GTK_CHECK_MENU_ITEM (
+            main_menu_download[MAIN_MENU_DOWNLOAD_PAUSE_AUTO_DL].widget),
+        gtm_pref.pause_auto_dl);
+    gtk_toggle_button_set_active (
+        GTK_TOGGLE_BUTTON (
+            main_toolbar[MAIN_TOOLBAR_PAUSE_AUTO_DL].widget),
+        gtm_pref.pause_auto_dl);
+
+    /* Reenable the disabled callbacks */
+    gtk_signal_handler_unblock_by_func (
+        GTK_OBJECT (
+            main_menu_download[MAIN_MENU_DOWNLOAD_PAUSE_AUTO_DL].widget),
+        GTK_SIGNAL_FUNC (toggle_pause_auto_dl_cmd),
+        file_list);
+    gtk_signal_handler_unblock_by_func (
+        GTK_OBJECT (main_toolbar[MAIN_TOOLBAR_PAUSE_AUTO_DL].widget),
+        GTK_SIGNAL_FUNC (toggle_pause_auto_dl_cmd),
+        file_list);
+}
+
+
 /* Function to change the toolbar style */
 void
 toolbar_update_style (void)
@@ -518,22 +606,63 @@ toolbar_update_style (void)
 }
 
 
-/* Function to update the download info page visibility */
+/* Function to set the download info page visibility */
 void
-main_window_update_dl_info_page_visibility (void)
+main_window_set_dl_info_page_visibility (GtkCList *file_list, gboolean visible)
 {
+    /* Record new visibility value */
+    gtm_pref.show_dl_info_page = visible;
+    gnome_config_set_bool ("/gtm/Preferences/show_dl_info_page",
+                           gtm_pref.show_dl_info_page);
+
+    /* Change the page visibility */
     if (gtm_pref.show_dl_info_page)
         gtk_widget_show (download_info);
     else
         gtk_widget_hide (download_info);
+
+    /* Update the toggle download info page button */
+    gtk_signal_handler_block_by_func (
+        GTK_OBJECT (main_toolbar[MAIN_TOOLBAR_DL_INFO_PAGE].widget),
+        GTK_SIGNAL_FUNC (toggle_dl_info_page_cmd),
+        GTK_CLIST (file_list));
+    gtk_toggle_button_set_active (
+        GTK_TOGGLE_BUTTON (
+            main_toolbar[MAIN_TOOLBAR_DL_INFO_PAGE].widget),
+        gtm_pref.show_dl_info_page);
+    gtk_signal_handler_unblock_by_func (
+        GTK_OBJECT (main_toolbar[MAIN_TOOLBAR_DL_INFO_PAGE].widget),
+        GTK_SIGNAL_FUNC (toggle_dl_info_page_cmd),
+        GTK_CLIST (file_list));
+
+    /* Update the auto hide download info page timeout */
+    update_auto_hide_dl_info_page_timeout ();
 }
 
 
+/* Function to update the auto hide download info page state */
+void
+main_window_update_auto_hide_dl_info_page (gboolean auto_hide, guint timeout)
+{
+    /* Set the new values */
+    gtm_pref.auto_hide_dl_info_page = auto_hide;
+    gtm_pref.auto_hide_dl_info_page_timeout = timeout;
+
+    /* Record the values on the config file */
+    gnome_config_set_bool ("auto_hide_dl_info_page",
+                           gtm_pref.auto_hide_dl_info_page);
+    gnome_config_set_int ("auto_hide_dl_info_page_timeout", 
+                          gtm_pref.auto_hide_dl_info_page_timeout);
+
+    /* Update the timeout */
+    update_auto_hide_dl_info_page_timeout ();
+}
+
 /* Init the application */
 GtkWidget *
 main_window_create (gchar *geometry)
 {
-    GtkWidget *file_list, *file_list_sw, *hbox, *appbar;
+    GtkWidget *file_list, *file_list_sw, *hbox, *appbar, *vbox;
     gint xpos, ypos, width, height, cur_w, cur_h;
 
     /* Create the application and handle some important signals */
@@ -549,9 +678,8 @@ main_window_create (gchar *geometry)
 
     /* Create the download information */
     download_info = download_info_create ();
-    main_window_update_dl_info_page_visibility ();
 
-    /* Create the menu, toolbar and status bar */
+    /* Create the menu and toolbar */
     gnome_app_create_menus_with_data (GNOME_APP (gtm_app), main_menu, 
                                       file_list);
     gnome_app_create_toolbar_with_data (GNOME_APP (gtm_app), main_toolbar,
@@ -563,17 +691,25 @@ main_window_create (gchar *geometry)
     gtk_widget_show (appbar);
     menu_toolbar_set_state (GTK_CLIST (file_list));
     menu_toolbar_set_auto_dl (GTK_CLIST (file_list));
+    menu_toolbar_update_pause_auto_dl (GTK_CLIST (file_list));
     toolbar_update_style ();
+    main_window_set_dl_info_page_visibility (GTK_CLIST (file_list),
+                                             gtm_pref.show_dl_info_page);
 
     /* Create a hbox widget and add the file list and download information */
     hbox = gtk_hbox_new (FALSE, 0);
     gtk_box_pack_start (GTK_BOX (hbox), file_list_sw, TRUE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (hbox), download_info, FALSE, FALSE, 0);
     gtk_widget_show (hbox);
-    gnome_app_set_contents (GNOME_APP (gtm_app), hbox);
-    download_info_update (NULL);
+
+    /* Create a vertical box and add the hbox and the log */
+    vbox = gtk_vbox_new (FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), log_create (), FALSE, FALSE, 0);
+    gtk_widget_show (vbox);
 
     /* Realize the main window */
+    gnome_app_set_contents (GNOME_APP (gtm_app), vbox);
     gtk_widget_realize (gtm_app);
 
     /* Parse the old geometry and check if the window is clipped with this
