@@ -55,6 +55,9 @@ guint next_file_id = 0;
 /* Variable used to disable events during startup */
 static gboolean startup;
 
+/* Variable holding the timeout id of the check network function */
+static gint check_network_timeout_id = -1;
+
 /* Session management */
 static gint 
 die (GnomeClient *client, gpointer client_data)
@@ -180,6 +183,17 @@ load_preferences (void)
 	gnome_config_get_int_with_default ("presume_protocol", &def);
     if (def)
 	gtm_pref.presume_protocol = PROTOCOL_HTTP;
+    gtm_pref.load_pause_auto_dl =
+        gnome_config_get_bool ("load_pause_auto_dl=FALSE");
+    if (gtm_pref.load_pause_auto_dl)
+        gtm_pref.pause_auto_dl =
+            gnome_config_get_bool ("pause_auto_dl=FALSE");
+    else
+        gtm_pref.pause_auto_dl = FALSE;
+    gtm_pref.auto_hide_dl_info_page =
+        gnome_config_get_bool ("auto_hide_dl_info_page=TRUE");
+    gtm_pref.auto_hide_dl_info_page_timeout = 
+	gnome_config_get_int ("auto_hide_dl_info_page_timeout=5000");
     gnome_config_pop_prefix ();
 
     return geometry;
@@ -282,6 +296,23 @@ report_event (gchar *which)
 }
 
 
+/* Update the check interface timeout */
+void
+update_check_interface_timeout (guint timeout)
+{
+    /* Set the new value */
+    gtm_pref.chk_interf_time = timeout;
+    gnome_config_set_int ("chk_interf_time", 
+                          gtm_pref.chk_interf_time);
+
+    /* Update the timeout */
+    if (check_network_timeout_id != -1)
+        gtk_timeout_remove (check_network_timeout_id);
+    check_network_timeout_id =
+        gtk_timeout_add (gtm_pref.chk_interf_time, check_network, NULL);
+}
+
+
 /* The main program where all begins */
 int 
 main (int argc, char *argv[])
@@ -294,7 +325,6 @@ main (int argc, char *argv[])
     GnomeClient *client;
     gchar *geometry;
     gint status;
-    gint check_time;
     gchar *url_to_get = NULL;
     struct poptOption gtm_popt_options[] = {
         { "get-url", 'g', POPT_ARG_STRING, &url_to_get, 0,
@@ -369,8 +399,8 @@ main (int argc, char *argv[])
     file_list_load_data (GTK_CLIST (dl_file_list));
 
     /* Install the timer */
-    check_time = gtk_timeout_add (gtm_pref.chk_interf_time, check_network,
-                                  NULL);
+    check_network_timeout_id = 
+        gtk_timeout_add (gtm_pref.chk_interf_time, check_network, NULL);
 
     /* Install a signal handler that saves the state of the application */
     signal (SIGINT, signal_handler);
@@ -398,11 +428,10 @@ main (int argc, char *argv[])
 	 * on the server */
 	GtkWidget *error;
 
-	error = gnome_message_box_new (_ (
+	error = gnome_error_dialog_parented (_ (
 	    "There is Another GNOME Transfer Manager running.\n"
 	    "Only one GNOME Transfer Manager can be running."), 
-				       GNOME_MESSAGE_BOX_ERROR,
-				       GNOME_STOCK_BUTTON_OK, NULL);
+                                             GTK_WINDOW (gtm_app) );
 	gnome_dialog_run_and_close (GNOME_DIALOG (error));
 	exit (1);
     }
@@ -414,7 +443,7 @@ main (int argc, char *argv[])
     gtk_main ();
 
     /* Destroy the timer */
-    gtk_timeout_remove(check_time);
+    gtk_timeout_remove (check_network_timeout_id);
     
     /* Save program geometry */
     save_geometry ();
